@@ -22,12 +22,9 @@ class YesEnergyItem:
 class YesEnergy(SourceConnector):
     def __init__(
         self,
-        username: str,
-        password: str,
         items: List[YesEnergyItem],
         stat: YesEnergyAggregation = YesEnergyAggregation.AVG,
     ) -> None:
         super().__init__(
-            uuid=UUID("207da43c-d284-44ee-90d0-61b96fa4df1c"),
-            parameters=dict(username=username, password=password, items=items, stat=stat),
+            uuid=UUID("207da43c-d284-44ee-90d0-61b96fa4df1c"), parameters=dict(items=items, stat=stat),
         )
