@@ -4,7 +4,7 @@ from myst.models import base_model
 
 
 class ModelGetInputSpecsSchema(base_model.BaseModel):
-    """A JSON Schema definition describing the inputs that this model can be used with."""
+    """A JSON Schema definition describing the inputs that this model can be used with. Output only."""
 
     __root__: Dict[str, Any]
 
