@@ -1,4 +1,4 @@
-from typing import Any, Optional
+from typing import Any, Dict, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
@@ -14,4 +14,4 @@ class OperationCreate(base_model.BaseModel):
     object_: Optional[Literal["Node"]] = Field("Node", alias="object")
     type: Optional[Literal["Operation"]] = "Operation"
     description: Optional[str] = None
-    parameters: Optional[Any] = None
+    parameters: Optional[Dict[str, Any]] = None
